==> totoui-0.3.0.tgz: package/lib/header.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

var _get = function get(_x, _x2, _x3) { var _again = true; _function: while (_again) { var object = _x, property = _x2, receiver = _x3; desc = parent = getter = undefined; _again = false; if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { _x = parent; _x2 = property; _x3 = receiver; _again = true; continue _function; } } else if ('value' in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } } };

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) subClass.__proto__ = superClass; }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _minxinsClassNameMixin = require('./minxins/ClassNameMixin');

var _minxinsClassNameMixin2 = _interopRequireDefault(_minxinsClassNameMixin);

var _iconJsx = require('./icon.js');

var _iconJsx2 = _interopRequireDefault(_iconJsx);

var _objectOmit = require('object.omit');

var _objectOmit2 = _interopRequireDefault(_objectOmit);

var Header = (function (_React$Component) {
    _inherits(Header, _React$Component);

    function Header(props) {
        _classCallCheck(this, Header);

        _get(Object.getPrototypeOf(Header.prototype), 'constructor', this).call(this, props);
        for (var v in _minxinsClassNameMixin2['default']) {
            this[v] = _minxinsClassNameMixin2['default'][v].bind(this);
        }
        this.renderTitle = this.renderTitle.bind(this);
        this.renderNav = this.renderNav.bind(this);
    }

    _createClass(Header, [{
        key: 'renderTitle',
        value: function renderTitle() {
            return this.props.title ? _react2['default'].createElement(
                'h1',
                {
                    className: this.prefixClass('title'),
                    onTouchStart: this.props.onSelect.bind(this, {
                        title: this.props.title,
                        link: this.props.link
                    }) },
                this.props.link ? _react2['default'].createElement(
                    'a',
                    { href: this.props.link },
                    this.props.title
                ) : this.props.title
            ) : null;
        }
    }, {
        key: 'renderNav',
        value: function renderNav(position) {
            var data = this.props.data;
            var renderItem = (function (item, i) {
                return _react2['default'].createElement(
                    'a',
                    { href: item.link,
                        onTouchStart: this.props.onSelect.bind(this, item),
                        key: 'headerNavItem' + i },
                    item.title ? _react2['default'].createElement(
                        'span',
                        { className: this.prefixClass('nav-title') },
                        item.title
                    ) : null,
                    item.customIcon ? _react2['default'].createElement('img', { src: item.customIcon, alt: item.title || null }) : item.icon ? _react2['default'].createElement(_iconJsx2['default'], {
                        className: this.prefixClass('icon'),
                        icon: item.icon }) : null
                );
            }).bind(this);

            return data && data[position] ? _react2['default'].createElement(
                'div',
                {
                    className: (0, _classnames2['default'])(this.prefixClass('nav'), this.prefixClass(position)) },
                data[position].map(function (item, i) {
                    return renderItem(item, i);
                })
            ) : null;
        }
    }, {
        key: 'render',
        value: function render() {
            var classSet = this.getClassSet();

            // am-header-fixed: fixed header
            classSet[this.prefixClass('fixed')] = this.props.fixed;

            return _react2['default'].createElement(
                'header',
                _extends({}, (0, _objectOmit2['default'])(this.props, ['data', 'title']), {
                    'data-am-widget': this.props.classPrefix,
                    className: (0, _classnames2['default'])(this.props.className, classSet) }),
                this.renderNav('left'),
                this.renderTitle(),
                this.renderNav('right')
            );
        }
    }]);

    return Header;
})(_react2['default'].Component);

Header.displayName = "Header";

Header.propTypes = {
    classPrefix: _react2['default'].PropTypes.string,
    theme: _react2['default'].PropTypes.oneOf(['default']),
    data: _react2['default'].PropTypes.object,
    fixed: _react2['default'].PropTypes.bool,
    title: _react2['default'].PropTypes.node,
    link: _react2['default'].PropTypes.string,
    onSelect: _react2['default'].PropTypes.func
};

Header.defaultProps = {
    classPrefix: 'header',
    theme: 'default',
    onSelect: function onSelect() {}
};

module.exports = Header;

==> totoui-0.5.1.tgz: package/lib/header.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

var _get = function get(_x, _x2, _x3) { var _again = true; _function: while (_again) { var object = _x, property = _x2, receiver = _x3; _again = false; if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { _x = parent; _x2 = property; _x3 = receiver; _again = true; desc = parent = undefined; continue _function; } } else if ('value' in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } } };

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _mixinsClassNameMixin = require('./mixins/ClassNameMixin');

var _mixinsClassNameMixin2 = _interopRequireDefault(_mixinsClassNameMixin);

var _iconJsx = require('./icon.js');

var _iconJsx2 = _interopRequireDefault(_iconJsx);

var _objectOmit = require('object.omit');

var _objectOmit2 = _interopRequireDefault(_objectOmit);

var Header = (function (_React$Component) {
    _inherits(Header, _React$Component);

    function Header(props) {
        _classCallCheck(this, Header);

        _get(Object.getPrototypeOf(Header.prototype), 'constructor', this).call(this, props);
        for (var v in _mixinsClassNameMixin2['default']) {
            this[v] = _mixinsClassNameMixin2['default'][v].bind(this);
        }
        this.renderTitle = this.renderTitle.bind(this);
        this.renderNav = this.renderNav.bind(this);
    }

    _createClass(Header, [{
        key: 'renderTitle',
        value: function renderTitle() {
            return this.props.title ? _react2['default'].createElement(
                'h1',
                {
                    className: this.prefixClass('title'),
                    onTouchStart: this.props.onSelect.bind(this, {
                        title: this.props.title,
                        link: this.props.link
                    }) },
                this.props.link ? _react2['default'].createElement(
                    'a',
                    { href: this.props.link },
                    this.props.title
                ) : this.props.title
            ) : null;
        }
    }, {
        key: 'renderNav',
        value: function renderNav(position) {
            var data = this.props.data;
            var renderItem = (function (item, i) {
                return _react2['default'].createElement(
                    'a',
                    { href: item.link,
                        onTouchStart: this.props.onSelect.bind(this, item),
                        key: 'headerNavItem' + i },
                    item.title ? _react2['default'].createElement(
                        'span',
                        { className: this.prefixClass('nav-title') },
                        item.title
                    ) : null,
                    item.customIcon ? _react2['default'].createElement('img', { src: item.customIcon, alt: item.title || null }) : item.icon ? _react2['default'].createElement(_iconJsx2['default'], {
                        className: this.prefixClass('icon'),
                        icon: item.icon }) : null
                );
            }).bind(this);

            return data && data[position] ? _react2['default'].createElement(
                'div',
                {
                    className: (0, _classnames2['default'])(this.prefixClass('nav'), this.prefixClass(position)) },
                data[position].map(function (item, i) {
                    return renderItem(item, i);
                })
            ) : null;
        }
    }, {
        key: 'render',
        value: function render() {
            var classSet = this.getClassSet();

            // am-header-fixed: fixed header
            classSet[this.prefixClass('fixed')] = this.props.fixed;

            return _react2['default'].createElement(
                'header',
                _extends({}, (0, _objectOmit2['default'])(this.props, ['data', 'title']), {
                    'data-widget': this.props.classPrefix,
                    className: (0, _classnames2['default'])(this.props.className, classSet) }),
                this.renderNav('left'),
                this.renderTitle(),
                this.renderNav('right')
            );
        }
    }]);

    return Header;
})(_react2['default'].Component);

Header.displayName = "Header";

Header.propTypes = {
    classPrefix: _react2['default'].PropTypes.string,
    theme: _react2['default'].PropTypes.oneOf(['default']),
    data: _react2['default'].PropTypes.object,
    fixed: _react2['default'].PropTypes.bool,
    title: _react2['default'].PropTypes.node,
    link: _react2['default'].PropTypes.string,
    onSelect: _react2['default'].PropTypes.func
};

Header.defaultProps = {
    classPrefix: 'header',
    theme: 'default',
    onSelect: function onSelect() {}
};

module.exports = Header;
